#[tauri_command]Expand description
Marks a function as both a Tyzen command and a Tauri command.
Shorthand for applying both #[tyzen::command] and #[tauri::command].
#[tauri_command]Marks a function as both a Tyzen command and a Tauri command.
Shorthand for applying both #[tyzen::command] and #[tauri::command].