#[derive(Event)]
{
// Attributes available to this derive:
#[tyzen]
#[event]
}
Derives the TsEvent trait for a struct.
This allows the struct to be used with the emit utility on the frontend.
#[derive(Event)]
{
// Attributes available to this derive:
#[tyzen]
#[event]
}
Derives the TsEvent trait for a struct.
This allows the struct to be used with the emit utility on the frontend.